#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "web"
"""
API_VERSION = "1.4.0"

from . import environment
from . import domain
from . import connectivity
from . import replication
from . import registration
from . import fault
from . import network
from . import database
from . import user
from . import delphix
from . import host
from . import system
from . import capacity
from . import action
from . import analytics
from . import group
from . import permission
from . import notification
from . import policy
from . import session
from . import timeflow
from . import objects
from . import authorization
from . import role
from . import toolkit
from . import jetstream
from . import service
from . import repository
from . import data
from . import snapshot
from . import alert
from . import storage
from . import job
from . import source
from . import sourceconfig
from . import namespace
from . import about
